@@ -198,7 +198,7 @@ class SE3(jdc.EnforcedAnnotationsMixin, _base.SEBase[SO3]):
 
     @staticmethod
     @overrides
-    def sample_uniform(key: jax.random.KeyArray) -> "SE3":
+    def sample_uniform(key: hints.KeyArray) -> "SE3":
         key0, key1 = jax.random.split(key)
         return SE3.from_rotation_and_translation(
             rotation=SO3.sample_uniform(key0),
